## Building and Running from Source

### **Prerequisites**
- Ensure you have **CMake (>=3.30)**
- Use a supported toolchain: **MinGW or MSVC**

### **Steps to Build and Install**
#### **1. Generate Build Files**
Run CMake to configure the build system. **You must specify an install location**:
```sh
cmake -B build -DCMAKE_INSTALL_PREFIX=./cmake-install
```

- This creates a `build/` directory with the necessary build files.
- `./cmake-install/` will be the location where the files are installed, feel free to change this.

#### **2. Build the Project**
```sh
cmake --build build
```

#### **2. Run the Install Command**
```sh
cmake --install build
```

### Running the program
After installation, you can run the executable from the `./cmake-install` directory:
```sh
./cmake-install/bin/LightShow
```


NOTE:
If you want to use export compile commands you need to use
```sh
-DUSE_COMPILE_COMMANDS=ON
```

### **C++ Modules Support**
To build and use **C++20 Modules**, ensure the following prerequisites are met:

#### **1. Compiler Support**
You need a compiler that supports **C++20 Modules**. The following versions are required:
- **GCC 11+** (Recommended: **GCC 14.2.0+**)
- **Clang 10+**
- **MSVC 19.30+ (Visual Studio 2022+)**

To check your compiler version, run:
```sh
g++ --version
```
Ensure it outputs GCC 11+, preferably GCC 14.2.0 or later. You can check if your compiler supports CPP Modules [on this page](https://en.cppreference.com/w/cpp/compiler_support/20)